@@ -1,5 +1,5 @@
 /*
- * Copyright Daniel Silverstone <dsilvers@digital-scurf.org> 2006
+ * Copyright Daniel Silverstone <dsilvers@digital-scurf.org> 2006-2011
  */
 
 #include "config.h"
@@ -176,7 +176,7 @@ main( int argc, char **argv )
 gfsplit (" PACKAGE_STRING ")\n\
 Written by Daniel Silverstone.\n\
 \n\
-Copyright (C) 2006 Daniel Silverstone <dsilvers@digital-scurf.org>\n\
+Copyright 2006-2011 Daniel Silverstone <dsilvers@digital-scurf.org>\n\
 This is free software; see the source for copying conditions.  There is NO\n\
 warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n\
 " );
@@ -191,7 +191,7 @@ warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n\
       sharecount = strtoul( optarg, &endptr, 10 );
       if( *endptr != 0 || *optarg == 0 || 
           sharecount < 2 || sharecount > 255 ) {
-        fprintf( stderr, "%s: Invalid argument to option -n\n", progname );
+        fprintf( stderr, "%s: Invalid argument to option -m\n", progname );
         usage( stderr );
         return 1;
       }
@@ -200,7 +200,7 @@ warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n\
       threshold = strtoul( optarg, &endptr, 10 );
       if( *endptr != 0 || *optarg == 0 || 
           threshold < 2 || threshold > sharecount) {
-        fprintf( stderr, "%s: Invalid argument to option -t\n", progname );
+        fprintf( stderr, "%s: Invalid argument to option -n\n", progname );
         usage( stderr );
         return 1;
       }
